@@ -1,7 +1,7 @@
 /* parser.c -- parser used by timsieved
  * Tim Martin
  * 9/21/99
- * $Id: parser.c,v 1.30 2003/07/22 19:17:35 rjs3 Exp $
+ * $Id: parser.c,v 1.31.2.2 2004/02/18 14:43:29 rjs3 Exp $
  */
 /*
  * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
@@ -56,8 +56,9 @@
 #include <sasl/sasl.h>
 #include <sasl/saslutil.h>
 
+#include <com_err.h>
+
 #include "actions.h"
-#include "com_err.h"
 #include "exitcodes.h"
 #include "lex.h"
 #include "mboxlist.h"
@@ -203,7 +204,7 @@ int parser(struct protstream *sieved_out, struct protstream *sieved_in)
   case HAVESPACE:
       if (timlex(NULL, NULL, sieved_in)!=SPACE)
       {
-	  error_msg = "SPACE must occur after PUTSCRIPT";
+	  error_msg = "SPACE must occur after HAVESPACE";
 	  goto error;
       }
       
@@ -542,8 +543,13 @@ static int cmd_authenticate(struct protstream *sieved_out,
     {
       clientin=(char *) malloc(str->len*2);
 
-      sasl_result=sasl_decode64(string_DATAPTR(str), str->len,
-				clientin, str->len*2, &clientinlen);
+      if (str->len) {
+	  sasl_result=sasl_decode64(string_DATAPTR(str), str->len,
+				    clientin, str->len*2, &clientinlen);
+      } else {
+	  clientinlen = 0;
+	  sasl_result = SASL_OK;
+      }
 
       if (sasl_result!=SASL_OK)
       {
